@@ -30,6 +30,7 @@
 #include <gtk/gtkmessagedialog.h>
 #include <libgnome/libgnome.h>
 #include <libgnomeui/gnome-about.h>
+#include <libgnomeui/gnome-icon-theme.h>
 #define WNCK_I_KNOW_THIS_IS_UNSTABLE
 #include <libwnck/screen.h>
 #include "egg-screen-help.h"
@@ -52,6 +53,8 @@ typedef struct {
         WnckScreen *wnck_screen;
 
         guint showing_desktop : 1;
+
+	GnomeIconTheme *icon_theme;
 } ShowDesktopData;
 
 static void display_help_dialog  (BonoboUIComponent *uic,
@@ -255,6 +258,7 @@ applet_destroyed (GtkWidget       *applet,
                   ShowDesktopData *sdd)
 {
         g_object_unref (G_OBJECT (sdd->icon));
+	g_object_unref (sdd->icon_theme);
 
 	if (sdd->about_dialog) {
 		gtk_widget_destroy (sdd->about_dialog);
@@ -281,7 +285,7 @@ show_desktop_applet_fill (PanelApplet *applet)
         ShowDesktopData *sdd;
         char *file;
         GError *error;
-        AtkObject *atk_obj;
+	AtkObject *atk_obj;
 
 	panel_applet_set_flags (applet, PANEL_APPLET_EXPAND_MINOR);
 
@@ -289,8 +293,11 @@ show_desktop_applet_fill (PanelApplet *applet)
 
         sdd->applet = GTK_WIDGET (applet);
 
-        file = gnome_program_locate_file (NULL, GNOME_FILE_DOMAIN_PIXMAP,
-                                          "gnome-show-desktop.png", TRUE, NULL);
+	sdd->icon_theme = gnome_icon_theme_new ();
+	gnome_icon_theme_set_allow_svg (sdd->icon_theme, TRUE);
+	file = gnome_icon_theme_lookup_icon (sdd->icon_theme,
+					     "gnome-fs-desktop", 48,
+					     NULL, NULL);
         error = NULL;
         if (file) {
                 sdd->icon = gdk_pixbuf_new_from_file (file, &error);
@@ -328,9 +335,8 @@ show_desktop_applet_fill (PanelApplet *applet)
         update_icon (sdd);
 
         sdd->button = gtk_toggle_button_new ();
-        atk_obj = gtk_widget_get_accessible (sdd->button);
-        atk_object_set_name (atk_obj, _("Show Desktop Button"));
-
+	atk_obj = gtk_widget_get_accessible (sdd->button);
+	atk_object_set_name (atk_obj, _("Show Desktop Button"));
         g_signal_connect (G_OBJECT (sdd->button), "button_press_event",
                           G_CALLBACK (do_not_eat_button_press), NULL);
 
