@@ -55,6 +55,7 @@ typedef struct {
 	GtkWidget *never_group_radio;
 	GtkWidget *auto_group_radio;
 	GtkWidget *always_group_radio;
+	GtkWidget *minimized_windows_label;
 	GtkWidget *move_minimized_radio;
 	GtkWidget *change_workspace_radio;
 
@@ -289,6 +290,13 @@ tasklist_properties_update_content_radio (TasklistData *tasklist)
 	
         if (!gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (button)))
 		gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (button), TRUE);
+
+	gtk_widget_set_sensitive (tasklist->minimized_windows_label,
+				  tasklist->include_all_workspaces);
+	gtk_widget_set_sensitive (tasklist->move_minimized_radio,
+				  tasklist->include_all_workspaces);
+	gtk_widget_set_sensitive (tasklist->change_workspace_radio,
+				  tasklist->include_all_workspaces);
 }
 
 static void
@@ -730,6 +738,17 @@ window_list_applet_fill (PanelApplet *applet)
 					   NULL,
 					   tasklist_menu_verbs, 
 					   tasklist);
+
+	if (panel_applet_get_locked_down (PANEL_APPLET (tasklist->applet))) {
+		BonoboUIComponent *popup_component;
+
+		popup_component = panel_applet_get_popup_component (PANEL_APPLET (tasklist->applet));
+
+		bonobo_ui_component_set_prop (popup_component,
+					      "/commands/TasklistPreferences",
+					      "hidden", "1",
+					      NULL);
+	}
 	
 	return TRUE;
 }
@@ -793,13 +812,15 @@ display_about_dialog (BonoboUIComponent *uic,
 		return;
 	}
 
-	file = gnome_program_locate_file (NULL, GNOME_FILE_DOMAIN_PIXMAP, "gnome-windows.png", TRUE, NULL);
+	file = gnome_icon_theme_lookup_icon (tasklist->icon_theme,
+					     "panel-window-list",
+					     48, NULL, NULL);
 	pixbuf = gdk_pixbuf_new_from_file (file, NULL);
 	g_free(file);
 
 	tasklist->about = gnome_about_new (_("Window List"), VERSION,
 				 "Copyright \xc2\xa9 2001-2002 Red Hat, Inc.",
-				 _("The Window List shows a list of all visible windows and lets you browse them."),
+				 _("The Window List shows a list of all windows and lets you browse them."),
 				 authors,
 				 documenters,
 				 strcmp (translator_credits, "translator_credits") != 0 ? translator_credits : NULL,
@@ -959,6 +980,7 @@ setup_dialog (GladeXML     *xml,
 			   "always_group_radio",
 			   "group_windows" /* key */);
 
+	tasklist->minimized_windows_label = WID ("minimized_windows_label");
 	tasklist->move_minimized_radio = WID ("move_minimized_radio");
 	tasklist->change_workspace_radio = WID ("change_workspace_radio");
 
@@ -1042,6 +1064,8 @@ display_properties_dialog (BonoboUIComponent *uic,
 			   TasklistData      *tasklist,
 			   const gchar       *verbname)
 {
+	gchar *window_icon;
+
 	if (tasklist->properties_dialog == NULL) {
 		GladeXML  *xml;
 
@@ -1056,8 +1080,14 @@ display_properties_dialog (BonoboUIComponent *uic,
 		g_object_unref (G_OBJECT (xml));
 	}
 
-	gnome_window_icon_set_from_file (GTK_WINDOW (tasklist->properties_dialog), 
-					 GNOME_ICONDIR "/gnome-windows.png");
+	window_icon = gnome_icon_theme_lookup_icon (tasklist->icon_theme,
+						    "panel-window-list",
+						    48, NULL, NULL);
+	if (window_icon) {
+		gnome_window_icon_set_from_file (GTK_WINDOW (tasklist->properties_dialog), window_icon);
+		g_free (window_icon);
+	}
+
 	gtk_window_set_resizable (GTK_WINDOW (tasklist->properties_dialog), FALSE);
 	gtk_window_set_screen (GTK_WINDOW (tasklist->properties_dialog),
 			       gtk_widget_get_screen (tasklist->applet));
