@@ -39,6 +39,8 @@
 #include "panel-globals.h"
 #include "panel-profile.h"
 
+#define PANEL_MENU_BAR_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), PANEL_TYPE_MENU_BAR, PanelMenuBarPrivate))
+
 #define MENU_FLAGS (MAIN_MENU_SYSTEM | MAIN_MENU_DISTRIBUTION_SUB)
 
 enum {
@@ -114,17 +116,19 @@ panel_menu_bar_append_actions_menu (PanelMenuBar *menubar)
 			  G_CALLBACK (gtk_widget_destroyed),
 			  &menubar->priv->actions_menu);
 
-	panel_menu_bar_append_action_item (
-			menubar,
-			menubar->priv->actions_menu,
-			_("Run Application..."),
-			PANEL_STOCK_RUN,
-			_("Run an Application by entering a command"),
-			"ACTION:run:NEW",
-			G_CALLBACK (panel_action_run_program));
+	if ( ! panel_profile_get_inhibit_command_line ()) {
+		panel_menu_bar_append_action_item (
+						   menubar,
+						   menubar->priv->actions_menu,
+						   _("Run Application..."),
+						   PANEL_STOCK_RUN,
+						   _("Run an Application by entering a command"),
+						   "ACTION:run:NEW",
+						   G_CALLBACK (panel_action_run_program));
 
-	item = gtk_separator_menu_item_new ();
-	gtk_menu_shell_append (GTK_MENU_SHELL (menubar->priv->actions_menu), item);
+		item = gtk_separator_menu_item_new ();
+		gtk_menu_shell_append (GTK_MENU_SHELL (menubar->priv->actions_menu), item);
+	}
 
 	if (panel_is_program_in_path  ("gnome-search-tool"))
 		panel_menu_bar_append_action_item (
@@ -186,7 +190,7 @@ panel_menu_bar_instance_init (PanelMenuBar      *menubar,
 	GtkWidget *item;
 	GtkWidget *image;
 
-	menubar->priv = g_new0 (PanelMenuBarPrivate, 1);
+	menubar->priv = PANEL_MENU_BAR_GET_PRIVATE (menubar);
 
 	menubar->priv->info = NULL;
 
@@ -220,19 +224,6 @@ panel_menu_bar_instance_init (PanelMenuBar      *menubar,
 	panel_menu_bar_append_actions_menu (menubar);
 }
 
-static void
-panel_menu_bar_finalize (GObject *object)
-{
-	PanelMenuBar *menubar = PANEL_MENU_BAR (object);
-
-	menubar->priv->info = NULL;
-
-	g_free (menubar->priv);
-	menubar->priv = NULL;
-
-	parent_class->finalize (object);
-}
-
 static void
 panel_menu_bar_parent_set (GtkWidget *widget,
 			   GtkWidget *previous_parent)
@@ -250,18 +241,16 @@ panel_menu_bar_parent_set (GtkWidget *widget,
 }
 
 static void
-panel_menu_bar_class_init (PanelMenuBarClass *klass,
-			   gpointer           dummy)
+panel_menu_bar_class_init (PanelMenuBarClass *klass)
 {
-	GObjectClass   *gobject_class = (GObjectClass   *) klass;
 	GtkWidgetClass *widget_class  = (GtkWidgetClass *) klass;
 
 	parent_class = g_type_class_peek_parent (klass);
 
-	gobject_class->finalize = panel_menu_bar_finalize;
-
 	widget_class->parent_set = panel_menu_bar_parent_set;
 
+	g_type_class_add_private (klass, sizeof (PanelMenuBarPrivate));
+
 	gtk_rc_parse_string (
 		"style \"panel-menubar-style\"\n"
 		"{\n"
@@ -361,7 +350,7 @@ panel_menu_bar_invoke_menu (PanelMenuBar *menubar,
 
 	screen = gtk_widget_get_screen (GTK_WIDGET (menubar));
 
-	panel_show_help (screen, "wgospanel.xml", NULL);
+	panel_show_help (screen, "wgospanel.xml", "gospanel-37");
 }
 
 void
@@ -369,11 +358,25 @@ panel_menu_bar_popup_menu (PanelMenuBar *menubar,
 			   guint32       activate_time)
 {
 	GtkMenu *menu;
+	GtkMenuShell *menu_shell;
 	
 	g_return_if_fail (PANEL_IS_MENU_BAR (menubar));
 
 	menu = GTK_MENU (menubar->priv->applications_menu);
 
-	gtk_menu_shell_select_item (GTK_MENU_SHELL (menubar),
+	/* 
+	 * We need to call _gtk_menu_shell_activate() here as is done in 
+	 * window_key_press_handler in gtkmenubar.c which pops up menu
+	 * when F10 is pressed.
+         *
+	 * As that function is private its code is replicated here.
+	 */
+	menu_shell = GTK_MENU_SHELL (menubar);
+	if (!menu_shell->active) {
+		gtk_grab_add (GTK_WIDGET (menu_shell));
+		menu_shell->have_grab = TRUE;
+		menu_shell->active = TRUE;
+	}
+	gtk_menu_shell_select_item (menu_shell,
 				    gtk_menu_get_attach_widget (menu));
 }
