@@ -52,6 +52,8 @@
 #include "panel-applet-marshal.h"
 #include "panel-applet-enums.h"
 
+#define PANEL_APPLET_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), PANEL_TYPE_APPLET, PanelAppletPrivate))
+
 struct _PanelAppletPrivate {
 	PanelAppletShell           *shell;
 	BonoboControl              *control;
@@ -69,14 +71,14 @@ struct _PanelAppletPrivate {
 	guint                       size;
 	char                       *background;
 
-	GdkPixmap                  *bg_pixmap;
-
         int                        *size_hints;
         int                         size_hints_len;
 
 	gboolean                    moving_focus_out;
 	int                         focusable_child;
 	guint                       hierarchy_changed_id;
+
+	gboolean                    locked_down;
 };
 
 static GObjectClass *parent_class;
@@ -97,6 +99,7 @@ static guint panel_applet_signals [LAST_SIGNAL];
 #define PROPERTY_BACKGROUND "panel-applet-background"
 #define PROPERTY_FLAGS      "panel-applet-flags"
 #define PROPERTY_SIZE_HINTS "panel-applet-size-hints"
+#define PROPERTY_LOCKED_DOWN "panel-applet-locked-down"
 
 enum {
 	PROPERTY_ORIENT_IDX,
@@ -104,6 +107,7 @@ enum {
 	PROPERTY_BACKGROUND_IDX,
 	PROPERTY_FLAGS_IDX,
 	PROPERTY_SIZE_HINTS_IDX,
+	PROPERTY_LOCKED_DOWN_IDX,
 };
 
 static void
@@ -270,12 +274,9 @@ panel_applet_set_size_hints (PanelApplet      *applet,
 			     int               base_size)
 {
 	CORBA_sequence_CORBA_long *seq;
-	CORBA_Environment          env;
 	CORBA_any                  any;
 	int                        i;
 
-	CORBA_exception_init (&env);
-
 	seq = CORBA_sequence_CORBA_long__alloc ();
 	seq->_length = seq->_maximum = n_elements;
 	seq->_release = CORBA_TRUE;
@@ -291,11 +292,9 @@ panel_applet_set_size_hints (PanelApplet      *applet,
 	Bonobo_PropertyBag_setValue (BONOBO_OBJREF (applet->priv->prop_sack),
 				     PROPERTY_SIZE_HINTS,
 				     &any,
-				     &env);
+				     NULL);
 
 	CORBA_free (seq);
-
-	CORBA_exception_free (&env);
 }
 
 guint
@@ -314,6 +313,14 @@ panel_applet_get_orient (PanelApplet *applet)
 	return applet->priv->orient;
 }
 
+gboolean
+panel_applet_get_locked_down (PanelApplet *applet)
+{
+	g_return_val_if_fail (PANEL_IS_APPLET (applet), FALSE);
+
+	return applet->priv->locked_down;
+}
+
 void
 panel_applet_setup_menu (PanelApplet        *applet,
 			 const gchar        *xml,
@@ -405,9 +412,6 @@ panel_applet_finalize (GObject *object)
 		g_closure_unref (applet->priv->closure);
 	applet->priv->closure = NULL;
 
-	g_free (applet->priv);
-	applet->priv = NULL;
-
 	parent_class->finalize (object);
 }
 
@@ -722,6 +726,7 @@ panel_applet_focus (GtkWidget        *widget,
 			 */ 
 			GTK_WIDGET_SET_FLAGS (widget, GTK_CAN_FOCUS);
 			gtk_widget_grab_focus (widget);
+			GTK_WIDGET_UNSET_FLAGS (widget, GTK_CAN_FOCUS);
 			ret = TRUE;
 		}
 	}
@@ -797,24 +802,27 @@ panel_applet_get_pixmap (PanelApplet     *applet,
 			 int              x,
 			 int              y)
 {
-	GdkWindow *window;
-	GdkPixmap *retval;
-	GdkGC     *gc;
-	int        width;
-	int        height;
+	GdkPixmap  *pixmap;
+	GdkDisplay *display;
+	GdkPixmap  *retval;
+	GdkGC      *gc;
+	int         width;
+	int         height;
 
 	g_return_val_if_fail (PANEL_IS_APPLET (applet), NULL);
 
 	if (!GTK_WIDGET_REALIZED (applet))
 		return NULL;
 
-	window = gdk_window_lookup (xid);
-	if (window)
-		g_object_ref (window);
+	display = gdk_display_get_default ();
+	
+	pixmap = gdk_pixmap_lookup_for_display (display, xid);
+	if (pixmap)
+		g_object_ref (pixmap);
 	else
-		window = gdk_window_foreign_new (xid);
+		pixmap = gdk_pixmap_foreign_new_for_display (display, xid);
 
-	g_return_val_if_fail (window != NULL, NULL);
+	g_return_val_if_fail (pixmap != NULL, NULL);
 
 	gdk_drawable_get_size (GDK_DRAWABLE (GTK_WIDGET (applet)->window),
 			       &width, &height);
@@ -827,13 +835,13 @@ panel_applet_get_pixmap (PanelApplet     *applet,
 
 	gdk_draw_drawable (GDK_DRAWABLE (retval),
 			   gc, 
-			   GDK_DRAWABLE (window),
+			   GDK_DRAWABLE (pixmap),
 			   x, y,
 			   0, 0,
 			   width, height);
 
 	g_object_unref (gc);
-	g_object_unref (window);
+	g_object_unref (pixmap);
 
 	return retval;
 }
@@ -950,6 +958,9 @@ panel_applet_get_prop (BonoboPropertyBag *sack,
 			seq->_buffer [i] = applet->priv->size_hints [i];
 	}
 		break;
+	case PROPERTY_LOCKED_DOWN_IDX:
+		BONOBO_ARG_SET_BOOLEAN (arg, applet->priv->locked_down);
+		break;
 	default:
 		g_assert_not_reached ();
 		break;
@@ -1050,6 +1061,9 @@ panel_applet_set_prop (BonoboPropertyBag *sack,
 		applet->priv->size_hints_len = seq->_length;;
 	}
 		break;
+	case PROPERTY_LOCKED_DOWN_IDX:
+		applet->priv->locked_down = BONOBO_ARG_GET_BOOLEAN (arg);
+		break;
 	default:
 		g_assert_not_reached ();
 		break;
@@ -1105,6 +1119,14 @@ panel_applet_property_bag (PanelApplet *applet)
 				 _("Ranges that hint what sizes are acceptable for the applet"),
 				 Bonobo_PROPERTY_READABLE);
 
+	bonobo_property_bag_add (sack,
+				 PROPERTY_LOCKED_DOWN,
+				 PROPERTY_LOCKED_DOWN_IDX,
+				 BONOBO_ARG_BOOLEAN,
+				 NULL,
+				 _("The Applet's containing Panel is locked down"),
+				 Bonobo_PROPERTY_READABLE | Bonobo_PROPERTY_WRITEABLE);
+
 	return sack;
 }
 
@@ -1230,6 +1252,16 @@ panel_applet_item_handler_get_object (BonoboItemHandler *handler,
 				bonobo_pbclient_set_short (
 					BONOBO_OBJREF (applet->priv->prop_sack), PROPERTY_SIZE,
 					GNOME_Vertigo_PANEL_XX_LARGE, NULL);
+		} else if (!strcmp (option->key, "locked_down")) {
+			gboolean val = FALSE;
+			if (option->value[0] == 'T' ||
+			    option->value[0] == 't' ||
+			    option->value[0] == 'Y' ||
+			    option->value[0] == 'y' ||
+			    atoi (option->value) != 0)
+				val = TRUE;
+			bonobo_pbclient_set_boolean (BONOBO_OBJREF (applet->priv->prop_sack),
+						     PROPERTY_LOCKED_DOWN, val, NULL);
 		}
 	}
 
@@ -1266,8 +1298,7 @@ add_tab_bindings (GtkBindingSet   *binding_set,
 }
 
 static void
-panel_applet_class_init (PanelAppletClass *klass,
-			 gpointer          dummy)
+panel_applet_class_init (PanelAppletClass *klass)
 {
 	GObjectClass   *gobject_class = (GObjectClass *) klass;
 	GtkObjectClass *object_class = (GtkObjectClass *) klass;
@@ -1287,6 +1318,8 @@ panel_applet_class_init (PanelAppletClass *klass,
 
 	gobject_class->finalize = panel_applet_finalize;
 
+	g_type_class_add_private (klass, sizeof (PanelAppletPrivate));
+
 	panel_applet_signals [CHANGE_ORIENT] =
                 g_signal_new ("change_orient",
                               G_TYPE_FROM_CLASS (klass),
@@ -1348,7 +1381,7 @@ static void
 panel_applet_instance_init (PanelApplet      *applet,
 			    PanelAppletClass *klass)
 {
-	applet->priv = g_new0 (PanelAppletPrivate, 1);
+	applet->priv = PANEL_APPLET_GET_PRIVATE (applet);
 
 	applet->priv->client = gconf_client_get_default ();
 
